# Python Async Bittrex API Wrapper

This package is used by the Bittrex integration of Home Assistant.

## Example

View the example code in `example.py`.

## Feedback & Pull Requests

All feedback and Pull Requests are welcome!

## Development

Don't forget to create your venv

```` python
python3 -m venv venv
source venv/bin/activate

````
